@@ -110,6 +110,9 @@ atk_role_get_type (void)
       { ATK_ROLE_PAGE, "ATK_ROLE_PAGE", "page" },
       { ATK_ROLE_SECTION, "ATK_ROLE_SECTION", "section" },
       { ATK_ROLE_REDUNDANT_OBJECT, "ATK_ROLE_REDUNDANT_OBJECT", "redundant-object" },
+      { ATK_ROLE_FORM, "ATK_ROLE_FORM", "form" },
+      { ATK_ROLE_LINK, "ATK_ROLE_LINK", "link" },
+      { ATK_ROLE_INPUT_METHOD_WINDOW, "ATK_ROLE_INPUT_METHOD_WINDOW", "input-method-window" },
       { ATK_ROLE_LAST_DEFINED, "ATK_ROLE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -159,6 +162,9 @@ atk_relation_type_get_type (void)
       { ATK_RELATION_EMBEDDED_BY, "ATK_RELATION_EMBEDDED_BY", "embedded-by" },
       { ATK_RELATION_POPUP_FOR, "ATK_RELATION_POPUP_FOR", "popup-for" },
       { ATK_RELATION_PARENT_WINDOW_OF, "ATK_RELATION_PARENT_WINDOW_OF", "parent-window-of" },
+      { ATK_RELATION_DESCRIBED_BY, "ATK_RELATION_DESCRIBED_BY", "described-by" },
+      { ATK_RELATION_DESCRIPTION_FOR, "ATK_RELATION_DESCRIPTION_FOR", "description-for" },
+      { ATK_RELATION_NODE_PARENT_OF, "ATK_RELATION_NODE_PARENT_OF", "node-parent-of" },
       { ATK_RELATION_LAST_DEFINED, "ATK_RELATION_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -210,6 +216,9 @@ atk_state_type_get_type (void)
       { ATK_STATE_INVALID_ENTRY, "ATK_STATE_INVALID_ENTRY", "invalid-entry" },
       { ATK_STATE_SUPPORTS_AUTOCOMPLETION, "ATK_STATE_SUPPORTS_AUTOCOMPLETION", "supports-autocompletion" },
       { ATK_STATE_SELECTABLE_TEXT, "ATK_STATE_SELECTABLE_TEXT", "selectable-text" },
+      { ATK_STATE_DEFAULT, "ATK_STATE_DEFAULT", "default" },
+      { ATK_STATE_ANIMATED, "ATK_STATE_ANIMATED", "animated" },
+      { ATK_STATE_VISITED, "ATK_STATE_VISITED", "visited" },
       { ATK_STATE_LAST_DEFINED, "ATK_STATE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
